@@ -1,6 +1,6 @@
 /*
  *    GDMcommunication routines
- *    (c)2001 Queen of England, (c)2002 George Lebl
+ *    (c)2001 Queen of England, (c)2002,2003 George Lebl
  *    
  *    This program is free software; you can redistribute it and/or modify
  *    it under the terms of the GNU General Public License as published by
@@ -125,25 +125,25 @@ gdmcomm_call_gdm (const char *command, const char * auth_cookie, const char *min
 	addr.sun_family = AF_UNIX;
 
 	if (connect (fd, (struct sockaddr *)&addr, sizeof (addr)) < 0) {
-		close (fd);
+		VE_IGNORE_EINTR (close (fd));
 		return gdmcomm_call_gdm (command, auth_cookie, min_version, tries - 1);
 	}
 
 	/* Version check first */
 	ret = do_command (fd, GDM_SUP_VERSION, TRUE /* get_response */);
 	if (ret == NULL) {
-		close (fd);
+		VE_IGNORE_EINTR (close (fd));
 		return gdmcomm_call_gdm (command, auth_cookie, min_version, tries - 1);
 	}
 	if (strncmp (ret, "GDM ", strlen ("GDM ")) != 0) {
 		g_free (ret);
-		close (fd);
+		VE_IGNORE_EINTR (close (fd));
 		return NULL;
 	}
 	if ( ! version_ok_p (&ret[4], min_version)) {
 		g_free (ret);
 		do_command (fd, GDM_SUP_CLOSE, FALSE /* get_response */);
-		close (fd);
+		VE_IGNORE_EINTR (close (fd));
 		return NULL;
 	}
 	g_free (ret);
@@ -155,7 +155,7 @@ gdmcomm_call_gdm (const char *command, const char * auth_cookie, const char *min
 		ret = do_command (fd, auth_cmd, TRUE /* get_response */);
 		g_free (auth_cmd);
 		if (ret == NULL) {
-			close (fd);
+			VE_IGNORE_EINTR (close (fd));
 			return gdmcomm_call_gdm (command, auth_cookie,
 						 min_version, tries - 1);
 		}
@@ -163,7 +163,7 @@ gdmcomm_call_gdm (const char *command, const char * auth_cookie, const char *min
 		if (strcmp (ret, "OK") != 0) {
 			do_command (fd, GDM_SUP_CLOSE,
 				    FALSE /* get_response */);
-			close (fd);
+			VE_IGNORE_EINTR (close (fd));
 			/* returns the error */
 			return ret;
 		}
@@ -172,13 +172,13 @@ gdmcomm_call_gdm (const char *command, const char * auth_cookie, const char *min
 
 	ret = do_command (fd, command, TRUE /* get_response */);
 	if (ret == NULL) {
-		close (fd);
+		VE_IGNORE_EINTR (close (fd));
 		return gdmcomm_call_gdm (command, auth_cookie, min_version, tries - 1);
 	}
 
 	do_command (fd, GDM_SUP_CLOSE, FALSE /* get_response */);
 
-	close (fd);
+	VE_IGNORE_EINTR (close (fd));
 
 	return ret;
 }
@@ -189,13 +189,20 @@ gdmcomm_get_display (void)
 	static char *display = NULL;
 
 	if (display == NULL) {
-		display = g_strdup (gdk_get_display ());
+		char *p;
+
+		display = gdk_get_display ();
 		if (display == NULL) {
 			display = g_strdup (g_getenv ("DISPLAY"));
 			if (display == NULL) /*eek!*/ {
 				display = g_strdup (":0");
 			}
 		}
+
+		/* whack screen part, GDM doesn't like those */
+		p = strchr (display, '.');
+		if (p != NULL)
+			*p = '\0';
 	}
 
 	return display;
@@ -210,7 +217,7 @@ get_dispnum (void)
 		char *p;
 		number = g_strdup (gdmcomm_get_display ());
 
-		/* whee! handles even DECnet crap */
+		/* whee! handles even DECnet */
 		number = strchr (number, ':');
 		if (number != NULL) {
 			while (*number == ':') {
@@ -236,7 +243,7 @@ gdmcomm_get_a_cookie (gboolean binary)
 	char *cookie = NULL;
 	Xauth *xau;
 
-	fp = fopen (XauFileName (), "r");
+	VE_IGNORE_EINTR (fp = fopen (XauFileName (), "r"));
 	if (fp == NULL) {
 		return NULL;
 	}
@@ -280,7 +287,7 @@ gdmcomm_get_a_cookie (gboolean binary)
 
 		break;
 	}
-	fclose (fp);
+	VE_IGNORE_EINTR (fclose (fp));
 
 	return cookie;
 }
@@ -297,7 +304,7 @@ gdmcomm_get_auth_cookie (void)
 	if (tried)
 		return cookie;
 
-	fp = fopen (XauFileName (), "r");
+	VE_IGNORE_EINTR (fp = fopen (XauFileName (), "r"));
 	if (fp == NULL) {
 		cookie = NULL;
 		tried = TRUE;
@@ -352,7 +359,7 @@ gdmcomm_get_auth_cookie (void)
 		}
 		g_free (ret);
 	}
-	fclose (fp);
+	VE_IGNORE_EINTR (fclose (fp));
 
 	tried = TRUE;
 	return cookie;
@@ -365,16 +372,21 @@ gdmcomm_check (gboolean gui_bitching)
 	FILE *fp = NULL;
 	long pid;
 	char *pidfile;
+	struct stat s;
+	int statret;
 
 	pidfile = ve_config_get_string (ve_config_get (GDM_CONFIG_FILE),
 					GDM_KEY_PIDFILE);
 
 	pid = 0;
 	if (pidfile != NULL)
-		fp = fopen (pidfile, "r");
+		VE_IGNORE_EINTR (fp = fopen (pidfile, "r"));
 	if (fp != NULL) {
-		fscanf (fp, "%ld", &pid);
-		fclose (fp);
+		int r;
+		VE_IGNORE_EINTR (r = fscanf (fp, "%ld", &pid));
+		VE_IGNORE_EINTR (fclose (fp));
+		if (r != 1)
+			pid = 0;
 	}
 
 	g_free (pidfile);
@@ -384,23 +396,22 @@ gdmcomm_check (gboolean gui_bitching)
 	    (kill (pid, 0) < 0 &&
 	     errno != EPERM)) {
 		if (gui_bitching) {
-			dialog = gtk_message_dialog_new
+			dialog = ve_hig_dialog_new
 				(NULL /* parent */,
 				 GTK_DIALOG_MODAL /* flags */,
 				 GTK_MESSAGE_WARNING,
 				 GTK_BUTTONS_OK,
-				 "foo");
-			gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
-			gtk_label_set_markup
-				 (GTK_LABEL (GTK_MESSAGE_DIALOG (dialog)->label),
-				  _("<b>GDM (The GNOME Display Manager) "
-				    "is not running.</b>\n\n"
-				    "You might in fact be using a different "
-				    "display manager, such as KDM "
-				    "(KDE Display Manager or xdm).\n"
-				    "If you still wish to use this feature, "
-				    "either start GDM your self or ask your "
-				    "system administrator to start GDM."));
+				 FALSE /* markup */,
+				 _("GDM (The GNOME Display Manager) "
+				   "is not running."),
+				 "%s\n%s",
+				 _("You might in fact be using a different "
+				   "display manager, such as KDM "
+				   "(KDE Display Manager) or xdm."),
+				 _("If you still wish to use this feature, "
+				   "either start GDM yourself or ask your "
+				   "system administrator to start GDM."));
+
 			gtk_widget_show_all (dialog);
 			gtk_dialog_run (GTK_DIALOG (dialog));
 			gtk_widget_destroy (dialog);
@@ -408,17 +419,22 @@ gdmcomm_check (gboolean gui_bitching)
 		return FALSE;
 	}
 
-	if (access (GDM_SUP_SOCKET, R_OK|W_OK)) {
+	VE_IGNORE_EINTR (statret = stat (GDM_SUP_SOCKET, &s));
+	if (statret < 0 ||
+	    s.st_uid != 0 ||
+	    access (GDM_SUP_SOCKET, R_OK|W_OK) != 0) {
 		if (gui_bitching) {
-			dialog = gtk_message_dialog_new
+			dialog = ve_hig_dialog_new
 				(NULL /* parent */,
 				 GTK_DIALOG_MODAL /* flags */,
 				 GTK_MESSAGE_WARNING,
 				 GTK_BUTTONS_OK,
+				 FALSE /* markup */,
 				 _("Cannot communicate with GDM "
-				   "(The GNOME Display Manager), perhaps "
-				   "you have an old version running."));
-			gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
+				   "(The GNOME Display Manager)"),
+				 "%s",
+				 _("Perhaps you have an old version "
+				   "of GDM running."));
 			gtk_widget_show_all (dialog);
 			gtk_dialog_run (GTK_DIALOG (dialog));
 			gtk_widget_destroy (dialog);
@@ -462,12 +478,22 @@ gdmcomm_get_error_message (const char *ret, gboolean use_xnest)
 			return _("The X server is not available, "
 				 "it is likely that gdm is badly "
 				 "configured.");
+	} else if (strncmp (ret, "ERROR 7 ", strlen ("ERROR 7 ")) == 0) {
+		return _("Trying to set an unknown logout action, or trying "
+			 "to set a logout action which is not available.");
+	} else if (strncmp (ret, "ERROR 8 ", strlen ("ERROR 8 ")) == 0) {
+		return _("Virtual terminals not supported.");
+	} else if (strncmp (ret, "ERROR 9 ", strlen ("ERROR 9 ")) == 0) {
+		return _("Trying to change to an invalid virtual terminal number.");
 	} else if (strncmp (ret, "ERROR 50 ", strlen ("ERROR 50 ")) == 0) {
 		return _("Trying to update an unsupported configuration key.");
 	} else if (strncmp (ret, "ERROR 100 ", strlen ("ERROR 100 ")) == 0) {
 		return _("You do not seem to have authentication needed "
 			 "be for this operation.  Perhaps your .Xauthority "
 			 "file is not set up correctly.");
+	} else if (strncmp (ret, "ERROR 200 ", strlen ("ERROR 200 ")) == 0) {
+		return _("Too many messages were sent to gdm and it hung up"
+			 "on us.");
 	} else {
 		return _("Unknown error occured.");
 	}
