@@ -60,7 +60,7 @@ static Language languages [] = {
 	/*Note translate the A-M to the A-M you used in the group label */
 	{ N_("A-M|Arabic (Lebanon)"), "ar_LB", NULL, 0 },
 	/*Note translate the A-M to the A-M you used in the group label */
-	{ N_("A-M|Armenian"), "hy_AM", NULL, 0 },
+	{ N_("A-M|Armenian"), "hy_AM", "Հայերեն", 0 },
 	/*Note translate the A-M to the A-M you used in the group label */
 	{ N_("A-M|Azerbaijani"), "az_AZ", "Azərbaycanca", 0 },
 	/*Note translate the A-M to the A-M you used in the group label */
@@ -150,6 +150,8 @@ static Language languages [] = {
 	/*Note translate the A-M to the A-M you used in the group label */
 	{ N_("A-M|Kannada"), "kn_IN", "﻿ಕನ್ನಡ", 0 },
 	/*Note translate the A-M to the A-M you used in the group label */
+        /*Note translate the A-M to the A-M you used in the group label */
+        { N_("A-M|Kinyarwanda"), "rw_RW", "Kinyarwanda", 0 },
 	{ N_("A-M|Korean"), "ko_KR", "한국어", 0 },
 	/*Note translate the A-M to the A-M you used in the group label */
 	{ N_("A-M|Latvian"), "lv_LV", "Latviešu", 0 },
@@ -374,7 +376,7 @@ gdm_lang_name (const char *language,
 		char *full;
 		if (markup) {
 			full = g_strdup_printf
-				("%s (<span lang=\"%s\">%s</span>)",
+				("%s (%s)",
 				 name,
 				 lang->code,
 				 lang->untranslated);
@@ -411,7 +413,7 @@ gdm_lang_untranslated_name (const char *language,
 		return NULL;
 
 	if (markup && lang->untranslated != NULL) {
-		return g_strdup_printf ("<span lang=\"%s\">%s</span>",
+		return g_strdup_printf ("%s",
 					lang->code,
 					lang->untranslated);
 	} else {
