@@ -974,7 +974,7 @@ setup_greeter_option (const char *name,
 	    selected == NULL)
 		add_menuitem (menu, val, val, val, &selected);
 
-	/* FIXME: Evil, but GtkOptionMenu is SOOOO FUCKING STUPID! */
+	/* FIXME: Evil, but GtkOptionMenu is SOOOO STUPID! */
 	if (selected != NULL) {
 		if (GTK_MENU (menu)->old_active_menu_item)
 			gtk_widget_unref (GTK_MENU (menu)->old_active_menu_item);
@@ -2188,7 +2188,7 @@ delete_theme (GtkWidget *button, gpointer data)
 	GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
 	gtk_widget_show (button);
 
-	button = gtk_button_new_from_stock ("_Remove Theme");
+	button = gtk_button_new_from_stock (_("_Remove Theme"));
 	gtk_dialog_add_action_widget (GTK_DIALOG (dlg), button, GTK_RESPONSE_YES);
 	GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
 	gtk_widget_show (button);
