@@ -52,6 +52,10 @@ gchar *GdmHalt = NULL;
 gchar *GdmReboot = NULL;
 gchar *GdmSuspend = NULL;
 gchar *GdmConfigurator = NULL;
+gboolean GdmHaltFound = FALSE;
+gboolean GdmRebootFound = FALSE;
+gboolean GdmSuspendFound = FALSE;
+gboolean GdmConfiguratorFound = FALSE;
 gboolean GdmSystemMenu = TRUE;
 gboolean GdmConfigAvailable = TRUE;
 gboolean GdmChooserButton = TRUE;
@@ -79,6 +83,7 @@ gchar *GdmSoundOnLoginFile;
 gchar *GdmSoundProgram;
 
 gboolean GdmUseCirclesInEntry = FALSE;
+gboolean GdmUseInvisibleInEntry = FALSE;
 
 static gboolean used_defaults = FALSE;
 gint greeter_current_delay = 0;
@@ -128,6 +133,7 @@ greeter_parse_config (void)
       }
     GdmXineramaScreen = ve_config_get_int (config, GDM_KEY_XINERAMASCREEN);
     GdmUseCirclesInEntry = ve_config_get_bool (config, GDM_KEY_ENTRY_CIRCLES);
+    GdmUseInvisibleInEntry = ve_config_get_bool (config, GDM_KEY_ENTRY_INVISIBLE);
 
     GdmShowXtermFailsafeSession = ve_config_get_bool (config, GDM_KEY_SHOW_XTERM_FAILSAFE);
     GdmShowGnomeFailsafeSession = ve_config_get_bool (config, GDM_KEY_SHOW_GNOME_FAILSAFE);
@@ -148,6 +154,11 @@ greeter_parse_config (void)
     GdmInfoMsgFile = ve_config_get_string (config, GDM_KEY_INFO_MSG_FILE);
     GdmInfoMsgFont = ve_config_get_string (config, GDM_KEY_INFO_MSG_FONT);
 
+    GdmHaltFound = gdm_working_command_exists (GdmHalt);
+    GdmRebootFound = gdm_working_command_exists (GdmReboot);
+    GdmSuspendFound = gdm_working_command_exists (GdmSuspend);
+    GdmConfiguratorFound = gdm_working_command_exists (GdmConfigurator);
+
     GdmWelcome = ve_config_get_translated_string (config, greeter_Welcome_key);
     /* A hack! */
     if (strcmp (ve_sure_string (GdmWelcome), "Welcome") == 0) {
@@ -638,6 +649,7 @@ verify_gdm_version (void)
       gdm_common_setup_cursor (GDK_LEFT_PTR);
     
       gtk_dialog_run (GTK_DIALOG (dialog));
+      gtk_widget_destroy (dialog);
     
       return EXIT_SUCCESS;
     }
@@ -777,6 +789,9 @@ greeter_reread_config (int sig, gpointer data)
 	     ! gdm_common_bool_same (config,
 			  GdmUseCirclesInEntry,
 			  GDM_KEY_ENTRY_CIRCLES) ||
+	     ! gdm_common_bool_same (config,
+			  GdmUseInvisibleInEntry,
+			  GDM_KEY_ENTRY_INVISIBLE) ||
 	     ! gdm_common_bool_same (config,
 			  GdmShowXtermFailsafeSession,
 			  GDM_KEY_SHOW_XTERM_FAILSAFE) ||
@@ -1054,16 +1069,12 @@ main (int argc, char *argv[])
 	  gdm_gtk_theme = GdmGtkTheme;
 
   if ( ! ve_string_empty (gdm_gtk_theme)) {
-	  gchar *theme_gtk_dir = gtk_rc_get_theme_dir ();
-	  char *theme = g_strdup_printf ("%s/%s/gtk-2.0/gtkrc", theme_gtk_dir, gdm_gtk_theme);
-	  g_free (theme_gtk_dir);
-
-	  if( ! ve_string_empty (theme))
-		  gtk_rc_parse (theme);
-
-	  g_free (theme);
+	  gdm_set_theme (gdm_gtk_theme);
   }
-  
+
+  /* set default font size to 12 */
+  gtk_rc_parse_string("gtk-font-name=\"Sans 12\"\n");
+
   gdm_wm_screen_init (GdmXineramaScreen);
   
   r = verify_gdm_version ();
@@ -1186,6 +1197,7 @@ main (int argc, char *argv[])
         gdm_common_setup_cursor (GDK_LEFT_PTR);
     
         gtk_dialog_run (GTK_DIALOG (dialog));
+	gtk_widget_destroy (dialog);
 
 	if (DOING_GDM_DEVELOPMENT)
 	  {
@@ -1234,6 +1246,7 @@ main (int argc, char *argv[])
       gdm_common_setup_cursor (GDK_LEFT_PTR);
 
       gtk_dialog_run (GTK_DIALOG (dialog));
+      gtk_widget_destroy (dialog);
 
       root = NULL;
     }
@@ -1270,6 +1283,7 @@ main (int argc, char *argv[])
       gdm_common_setup_cursor (GDK_LEFT_PTR);
     
       gtk_dialog_run (GTK_DIALOG (dialog));
+      gtk_widget_destroy (dialog);
 
       execl (EXPANDED_BINDIR "/gdmlogin", EXPANDED_BINDIR "/gdmlogin", NULL);
       execlp ("gdmlogin", "gdmlogin", NULL);
@@ -1292,6 +1306,7 @@ main (int argc, char *argv[])
       gdm_common_setup_cursor (GDK_LEFT_PTR);
     
       gtk_dialog_run (GTK_DIALOG (dialog));
+      gtk_widget_destroy (dialog);
 
       _exit (DISPLAY_ABORT);
     }
@@ -1300,6 +1315,8 @@ main (int argc, char *argv[])
   
   greeter_setup_items ();
 
+  gdm_setup_blinking ();
+
   gtk_widget_show_all (window);
   gtk_window_move (GTK_WINDOW (window), gdm_wm_screen.x, gdm_wm_screen.y);
   gtk_widget_show_now (window);
