@@ -25,11 +25,13 @@
 /* For clist */
 #undef GTK_DISABLE_DEPRECATED
 
-#include <libgnome/libgnome.h>
-#include <libgnomeui/libgnomeui.h>
+#include <gtk/gtk.h>
 #include <glade/glade.h>
 
+#include "ve-i18n.h"
+
 #include "ve-misc.h"
+#include "ve-miscui.h"
 
 #include "glade-helper.h"
 
@@ -170,6 +172,7 @@ glade_helper_bad_interface (const char *filename, const char *widget,
 	GtkWidget *dlg;
 	char *typestring;
 	const char *typename;
+	char *tmp;
 
 	if (type != 0)
 		typename = g_type_name (type);
@@ -180,30 +183,36 @@ glade_helper_bad_interface (const char *filename, const char *widget,
 		typestring = g_strdup_printf (" (%s)", typename);
 	else
 		typestring = g_strdup ("");
+
+	tmp = ve_filename_to_utf8 (filename);
 	
-	dlg = gtk_message_dialog_new (NULL /* parent */,
-				      0 /* flags */,
-				      GTK_MESSAGE_ERROR,
-				      GTK_BUTTONS_CLOSE,
-				      _("An error occured while loading the user "
-					"interface\nelement %s%s from file %s.\n"
-					"Possibly the glade interface description was "
-					"corrupted.\n"
-					"%s cannot continue and will exit now.\n"
-					"You should check your "
-					"installation of %s or reinstall %s."),
-				      widget,
-				      typestring,
-				      filename,
-				      PACKAGE,
-				      PACKAGE,
-				      PACKAGE);
+	dlg = ve_hig_dialog_new (NULL /* parent */,
+				 0 /* flags */,
+				 GTK_MESSAGE_ERROR,
+				 GTK_BUTTONS_OK,
+				 FALSE /* markup */,
+				 _("Cannot load user interface"),
+				 _("An error occured while loading the user "
+				   "interface element %s%s from file %s.  "
+				   "Possibly the glade interface description was "
+				   "corrupted.  "
+				   "%s cannot continue and will exit now.  "
+				   "You should check your "
+				   "installation of %s or reinstall %s."),
+				 widget,
+				 typestring,
+				 tmp,
+				 PACKAGE,
+				 PACKAGE,
+				 PACKAGE);
 
 	g_free (typestring);
 
 	g_warning (_("Glade file is on crack! Make sure the correct "
 		     "file is installed!\nfile: %s widget: %s"),
-		   filename, widget);
+		   tmp, widget);
+
+	g_free (tmp);
 
 	gtk_dialog_run (GTK_DIALOG (dlg));
 	gtk_widget_destroy (dlg);
@@ -216,6 +225,7 @@ glade_helper_bad_columns (const char *filename, const char *widget,
 	GtkWidget *dlg;
 	char *typestring;
 	const char *typename;
+	char *tmp;
 
 	if (type != 0)
 		typename = g_type_name (type);
@@ -226,33 +236,50 @@ glade_helper_bad_columns (const char *filename, const char *widget,
 		typestring = g_strdup_printf (" (%s)", typename);
 	else
 		typestring = g_strdup ("");
+
+	tmp = ve_filename_to_utf8 (filename);
 	
-	dlg = gtk_message_dialog_new (NULL /* parent */,
-				      0 /* flags */,
-				      GTK_MESSAGE_ERROR,
-				      GTK_BUTTONS_CLOSE,
-				      _("An error occured while loading the user "
-					"interface\nelement %s%s from file %s.\n"
-					"CList type widget should have %d columns.\n"
-					"Possibly the glade interface description was "
-					"corrupted.\n"
-					"%s cannot continue and will exit now.\n"
-					"You should check your "
-					"installation of %s or reinstall %s."),
-				      widget,
-				      typestring,
-				      filename,
-				      columns,
-				      PACKAGE,
-				      PACKAGE,
-				      PACKAGE);
+	dlg = ve_hig_dialog_new (NULL /* parent */,
+				 0 /* flags */,
+				 GTK_MESSAGE_ERROR,
+				 GTK_BUTTONS_OK,
+				 FALSE /* markup */,
+				 _("Cannot load user interface"),
+				 ngettext ("An error occured while loading the "
+					   "user interface element %s%s from "
+					   "file %s. CList type widget should "
+					   "have %d column. Possibly the glade "
+					   "interface description was "
+					   "corrupted. %s cannot continue and "
+					   "will exit now. You should check "
+					   "your installation of %s or "
+					   "reinstall %s.",
+					   "An error occured while loading the "
+					   "user interface element %s%s from "
+					   "file %s. CList type widget should "
+					   "have %d columns. Possibly the "
+					   "glade interface description was "
+					   "corrupted. %s cannot continue and "
+					   "will exit now. You should check "
+					   "your installation of %s or "
+					   "reinstall %s.",
+					   columns),
+				 widget,
+				 typestring,
+				 tmp,
+				 columns,
+				 PACKAGE,
+				 PACKAGE,
+				 PACKAGE);
 
 	g_free (typestring);
 
 	g_warning (_("Glade file is on crack! Make sure the correct "
 		     "file is installed!\nfile: %s widget: %s "
 		     "expected clist columns: %d"),
-		   filename, widget, columns);
+		   tmp, widget, columns);
+
+	g_free (tmp);
 
 	gtk_dialog_run (GTK_DIALOG (dlg));
 	gtk_widget_destroy (dlg);
@@ -262,24 +289,32 @@ static void
 glade_helper_no_interface (const char *filename)
 {
 	GtkWidget *dlg;
+	char *tmp;
+
+	tmp = ve_filename_to_utf8 (filename);
 	
-	dlg = gtk_message_dialog_new (NULL /* parent */,
-				      0 /* flags */,
-				      GTK_MESSAGE_ERROR,
-				      GTK_BUTTONS_CLOSE,
-				      _("An error occured while loading the user "
-					"interface\nfrom file %s.\n"
-					"Possibly the glade interface description was "
-					"not found.\n"
-					"%s cannot continue and will exit now.\n"
-					"You should check your "
-					"installation of %s or reinstall %s."),
-				      filename,
-				      PACKAGE,
-				      PACKAGE,
-				      PACKAGE);
+	dlg = ve_hig_dialog_new (NULL /* parent */,
+				 0 /* flags */,
+				 GTK_MESSAGE_ERROR,
+				 GTK_BUTTONS_OK,
+				 FALSE /* markup */,
+				 _("Cannot load user interface"),
+				 _("An error occured while loading the user "
+				   "interface from file %s.  "
+				   "Possibly the glade interface description was "
+				   "not found.  "
+				   "%s cannot continue and will exit now.  "
+				   "You should check your "
+				   "installation of %s or reinstall %s."),
+				 tmp,
+				 PACKAGE,
+				 PACKAGE,
+				 PACKAGE);
+	gtk_dialog_set_has_separator (GTK_DIALOG (dlg), FALSE);
 	g_warning (_("No interface could be loaded, BAD! (file: %s)"),
-		   filename);
+		   tmp);
+
+	g_free (tmp);
 
 	gtk_dialog_run (GTK_DIALOG (dlg));
 	gtk_widget_destroy (dlg);
@@ -337,3 +372,27 @@ glade_helper_search_gnome_dirs (gboolean search_gnome_dirs)
 	ve_search_gnome_dirs = search_gnome_dirs;
 }
 
+/* Make label surrounded by tag (if tag = "tag" add <tag>text</tag>) */
+void
+glade_helper_tagify_label (GladeXML *xml,
+			   const char *name,
+			   const char *tag)
+{
+	const char *lbl;
+	char *s;
+	GtkWidget *label = glade_helper_get (xml, name, GTK_TYPE_WIDGET);
+	if (GTK_IS_BUTTON (label)) {
+		label = GTK_BIN(label)->child;
+	}
+	if ( ! GTK_IS_LABEL (label)) {
+		glade_helper_bad_interface (xml->filename,
+					    name,
+					    GTK_TYPE_LABEL);
+		exit (1);
+	}
+	lbl = gtk_label_get_text (GTK_LABEL (label));
+	s = g_strdup_printf ("<%s>%s</%s>", tag, lbl, tag);
+	gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
+	gtk_label_set_label (GTK_LABEL (label), s);
+	g_free (s);
+}
